bayespy.inference.vmp.nodes.expfamily.ExponentialFamily
=======================================================

.. currentmodule:: bayespy.inference.vmp.nodes.expfamily

.. autoclass:: ExponentialFamily

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree: generated/
   
      ~ExponentialFamily.__init__
      ~ExponentialFamily.add_plate_axis
      ~ExponentialFamily.broadcasting_multiplier
      ~ExponentialFamily.delete
      ~ExponentialFamily.get_gradient
      ~ExponentialFamily.get_mask
      ~ExponentialFamily.get_moments
      ~ExponentialFamily.get_parameters
      ~ExponentialFamily.get_riemannian_gradient
      ~ExponentialFamily.get_shape
      ~ExponentialFamily.has_plotter
      ~ExponentialFamily.initialize_from_parameters
      ~ExponentialFamily.initialize_from_prior
      ~ExponentialFamily.initialize_from_random
      ~ExponentialFamily.initialize_from_value
      ~ExponentialFamily.load
      ~ExponentialFamily.logpdf
      ~ExponentialFamily.lower_bound_contribution
      ~ExponentialFamily.lowerbound
      ~ExponentialFamily.move_plates
      ~ExponentialFamily.observe
      ~ExponentialFamily.pdf
      ~ExponentialFamily.plot
      ~ExponentialFamily.random
      ~ExponentialFamily.save
      ~ExponentialFamily.set_parameters
      ~ExponentialFamily.set_plotter
      ~ExponentialFamily.show
      ~ExponentialFamily.unobserve
      ~ExponentialFamily.update
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
      :toctree: generated/
   
      ~ExponentialFamily.dims
      ~ExponentialFamily.plates
      ~ExponentialFamily.plates_multiplier
   
   